@@ -25,6 +25,6 @@ class GPU:
                 ['cat', '/sys/class/thermal/thermal_zone0/temp'])
             temp = float(temp) / 1000
         except:
-            temp = 0.0
+            temp = -273.16  # use absolute zero for no reading
         temp = round(temp, 2)
         return temp
